@@ -59,56 +59,6 @@ enum Method
     defaultDense = 0 /*!< Default method proposed by Y. Freund */
 };
 
-/**
- * \brief Contains version 1.0 of Intel(R) oneAPI Data Analytics Library interface.
- */
-namespace interface1
-{
-/**
- * <a name="DAAL-CLASS-ALGORITHMS__BROWNBOOST__TRAINING__RESULT"></a>
- * \brief Provides methods to access final results obtained with the compute() method \DAAL_DEPRECATED
- *        of the BrownBoost training algorithm in the batch processing mode
- */
-class DAAL_EXPORT Result : public classifier::training::interface1::Result
-{
-public:
-    DECLARE_SERIALIZABLE_CAST(Result)
-
-    DAAL_DEPRECATED_VIRTUAL virtual ~Result() {}
-
-    /**
-     * Returns the model trained with the BrownBoost algorithm
-     * \param[in] id    Identifier of the result, \ref classifier::training::ResultId
-     * \return          Model trained with the BrownBoost algorithm
-     */
-    DAAL_DEPRECATED daal::algorithms::brownboost::interface1::ModelPtr get(classifier::training::ResultId id) const;
-
-    /**
-     * Allocates memory to store final results of BrownBoost training
-     * \param[in] input        %Input of the BrownBoost training algorithm
-     * \param[in] parameter     Parameters of the algorithm
-     * \param[in] method        BrownBoost computation method
-     */
-    template <typename algorithmFPType>
-    DAAL_EXPORT DAAL_DEPRECATED services::Status allocate(const daal::algorithms::Input * input, const daal::algorithms::Parameter * parameter,
-                                                          const int method);
-
-    DAAL_DEPRECATED services::Status check(const daal::algorithms::Input * input, const daal::algorithms::Parameter * parameter,
-                                           int method) const DAAL_C11_OVERRIDE;
-
-protected:
-    using daal::algorithms::interface1::Result::check;
-
-    /** \private */
-    template <typename Archive, bool onDeserialize>
-    services::Status serialImpl(Archive * arch)
-    {
-        return daal::algorithms::Result::serialImpl<Archive, onDeserialize>(arch);
-    }
-};
-typedef services::SharedPtr<interface1::Result> ResultPtr;
-} // namespace interface1
-
 /**
  * \brief Contains version 2.0 of Intel(R) oneAPI Data Analytics Library interface.
  */
