@@ -70,7 +70,12 @@ enum ResultNumericTableId
                                                            Computed when parameter.varImportance != none */
     outOfBagErrorPerObservation,                     /*!< %Numeric table 1x(number of observations) containing out-of-bag error value computed.
                                                            Computed when computeOutOfBagErrorPerObservation option is on */
-    lastResultId = outOfBagErrorPerObservation
+    outOfBagErrorAccuracy,                           /*!< %Numeric table 1x1 containing accuracy related to out-of-bag error.
+                                                           Computed when computeOutOfBagErrorAccuracy option is on */
+    outOfBagErrorDecisionFunction,                   /*!< %Numeric table (number of observations)x(number of classes)
+                                                           containing probabilities related to out-of-bag error computed.
+                                                           Computed when computeOutOfBagErrorDecisionFunction option is on */
+    lastResultId = outOfBagErrorDecisionFunction
 };
 
 /**
@@ -83,48 +88,6 @@ enum ResultEngineId
     lastResultEngineId = updatedEngine
 };
 
-/**
- * \brief Contains version 1.0 of Intel(R) oneAPI Data Analytics Library interface.
- */
-namespace interface1
-{
-/**
- * <a name="DAAL-STRUCT-ALGORITHMS__DECISION_FOREST__CLASSIFICATION__TRAINING__PARAMETER"></a>
- * \brief Decision forest algorithm parameters   \DAAL_DEPRECATED
- *
- * \snippet decision_forest/decision_forest_classification_training_types.h Parameter source code
- */
-/* [interface1::Parameter source code] */
-struct DAAL_EXPORT Parameter : public classifier::interface1::Parameter, public daal::algorithms::decision_forest::training::interface1::Parameter
-{
-    /** Default constructor */
-    DAAL_DEPRECATED Parameter(size_t nClasses) : classifier::interface1::Parameter(nClasses) {}
-    DAAL_DEPRECATED services::Status check() const DAAL_C11_OVERRIDE;
-};
-/* [interface1::Parameter source code] */
-} // namespace interface1
-
-/**
- * \brief Contains version 2.0 of Intel(R) oneAPI Data Analytics Library interface.
- */
-namespace interface2
-{
-/**
- * <a name="DAAL-STRUCT-ALGORITHMS__DECISION_FOREST__CLASSIFICATION__TRAINING__PARAMETER"></a>
- * \brief Decision forest algorithm parameters   \DAAL_DEPRECATED
- *
- * \snippet decision_forest/decision_forest_classification_training_types.h Parameter source code
- */
-/* [interface2::Parameter source code] */
-struct DAAL_EXPORT Parameter : public classifier::Parameter, public daal::algorithms::decision_forest::training::interface1::Parameter
-{
-    /** Default constructor */
-    DAAL_DEPRECATED Parameter(size_t nClasses) : classifier::Parameter(nClasses) {}
-    DAAL_DEPRECATED services::Status check() const DAAL_C11_OVERRIDE;
-};
-/* [interface2::Parameter source code] */
-} // namespace interface2
-
 /**
  * \brief Contains version 3.0 of Intel(R) oneAPI Data Analytics Library interface.
  */
