@@ -87,23 +87,6 @@ enum ResultNumericTableId
  */
 namespace interface1
 {
-/**
- * <a name="DAAL-STRUCT-ALGORITHMS__LOGISTIC_REGRESSION__PREDICTION__PARAMETER"></a>
- * \brief Parameters of the prediction algorithm  \DAAL_DEPRECATED
- *
- * \snippet logistic_regression/logistic_regression_predict_types.h Parameter source code
- */
-/* [Parameter source code] */
-struct DAAL_EXPORT Parameter : public daal::algorithms::classifier::interface1::Parameter
-{
-    DAAL_DEPRECATED Parameter(size_t nClasses = 2)
-        : daal::algorithms::classifier::interface1::Parameter(nClasses), resultsToCompute(computeClassesLabels)
-    {}
-    DAAL_DEPRECATED Parameter(const Parameter & o) : daal::algorithms::classifier::interface1::Parameter(o), resultsToCompute(o.resultsToCompute) {}
-    DAAL_UINT64 resultsToCompute; /*!< 64 bit integer flag that indicates the results to compute */
-};
-/* [Parameter source code] */
-
 /**
  * <a name="DAAL-CLASS-ALGORITHMS__LOGISTIC_REGRESSION__PREDICTION__INPUT"></a>
  * \brief Input objects in the prediction stage of the LOGISTIC_REGRESSION algorithm
@@ -157,78 +140,6 @@ public:
     services::Status check(const daal::algorithms::Parameter * parameter, int method) const DAAL_C11_OVERRIDE;
 };
 
-/**
-* <a name="DAAL-CLASS-ALGORITHMS__LOGISTIC_REGRESSION__PREDICTION__RESULT"></a>
-* \brief Provides interface for the result of model-based prediction   \DAAL_DEPRECATED
-*/
-class DAAL_EXPORT Result : public algorithms::classifier::prediction::interface1::Result
-{
-public:
-    DECLARE_SERIALIZABLE_CAST(Result)
-    DAAL_DEPRECATED Result();
-
-    /**
-    * Returns the result of model-based prediction
-    * \param[in] id    Identifier of the result
-    * \return          Result that corresponds to the given identifier
-    */
-    DAAL_DEPRECATED data_management::NumericTablePtr get(classifier::prediction::ResultId id) const;
-
-    /**
-    * Sets the result of model-based prediction
-    * \param[in] id      Identifier of the input object
-    * \param[in] value   %Input object
-    */
-    DAAL_DEPRECATED void set(classifier::prediction::ResultId id, const data_management::NumericTablePtr & value);
-
-    /**
-    * Returns the result of model-based prediction
-    * \param[in] id    Identifier of the result
-    * \return          Result that corresponds to the given identifier
-    */
-    DAAL_DEPRECATED data_management::NumericTablePtr get(ResultNumericTableId id) const;
-
-    /**
-    * Sets the result of model-based prediction
-    * \param[in] id      Identifier of the input object
-    * \param[in] value   %Input object
-    */
-    DAAL_DEPRECATED void set(ResultNumericTableId id, const data_management::NumericTablePtr & value);
-
-    /**
-    * Allocates memory to store a partial result of model-based prediction
-    * \param[in] input   %Input object
-    * \param[in] par     %Parameter of the algorithm
-    * \param[in] method  Algorithm method
-    * \return Status of allocation
-    */
-    template <typename algorithmFPType>
-    DAAL_EXPORT DAAL_DEPRECATED services::Status allocate(const daal::algorithms::Input * input, const daal::algorithms::Parameter * par,
-                                                          const int method);
-
-    /**
-    * Checks the result of model-based prediction
-    * \param[in] input   %Input object
-    * \param[in] par     %Parameter of the algorithm
-    * \param[in] method  Computation method
-    * \return Status of checking
-    */
-    DAAL_DEPRECATED services::Status check(const daal::algorithms::Input * input, const daal::algorithms::Parameter * par,
-                                           int method) const DAAL_C11_OVERRIDE;
-
-protected:
-    using daal::algorithms::interface1::Result::check;
-
-    /** \private */
-    template <typename Archive, bool onDeserialize>
-    services::Status serialImpl(Archive * arch)
-    {
-        return daal::algorithms::classifier::prediction::interface1::Result::serialImpl<Archive, onDeserialize>(arch);
-    }
-};
-typedef services::SharedPtr<Result> ResultPtr;
-typedef services::SharedPtr<const Result> ResultConstPtr;
-
 } // namespace interface1
 using interface1::Input;
 using classifier::Parameter;             /* Support of static backward compatibility */
