@@ -138,6 +138,11 @@ class InputIface : public daal::algorithms::Input
 public:
     InputIface(size_t nElements) : daal::algorithms::Input(nElements) {}
     InputIface(const InputIface & other) : daal::algorithms::Input(other) {}
+    InputIface & operator=(const InputIface & other)
+    {
+        daal::algorithms::Input::operator=(other);
+        return *this;
+    }
     virtual services::Status getNumberOfColumns(size_t & nCols) const = 0;
     virtual ~InputIface() {}
 };
@@ -151,6 +156,7 @@ class DAAL_EXPORT Input : public InputIface
 public:
     Input();
     Input(const Input & other);
+    Input & operator=(const Input & other);
 
     virtual ~Input() {}
 
@@ -361,6 +367,7 @@ class DAAL_EXPORT DistributedInput : public InputIface
 public:
     DistributedInput();
     DistributedInput(const DistributedInput & other);
+    DistributedInput & operator=(const DistributedInput & other);
 
     virtual ~DistributedInput() {}
 
