@@ -113,10 +113,6 @@
 #include "algorithms/association_rules/apriori_types.h"
 #include "algorithms/cholesky/cholesky.h"
 #include "algorithms/cholesky/cholesky_types.h"
-#include "algorithms/stump/stump_model.h"
-#include "algorithms/stump/stump_predict.h"
-#include "algorithms/stump/stump_training_batch.h"
-#include "algorithms/stump/stump_training_types.h"
 #include "algorithms/stump/stump_classification_model.h"
 #include "algorithms/stump/stump_classification_predict.h"
 #include "algorithms/stump/stump_classification_training_batch.h"
@@ -198,9 +194,6 @@
 #include "algorithms/qr/qr_distributed.h"
 #include "algorithms/pivoted_qr/pivoted_qr_types.h"
 #include "algorithms/pivoted_qr/pivoted_qr_batch.h"
-#include "algorithms/boosting/boosting_model.h"
-#include "algorithms/boosting/boosting_predict.h"
-#include "algorithms/boosting/boosting_training_batch.h"
 #include "algorithms/quantiles/quantiles_types.h"
 #include "algorithms/quantiles/quantiles_batch.h"
 #include "algorithms/implicit_als/implicit_als_model.h"
