@@ -59,9 +59,9 @@ struct infer_ops {
     void check_postconditions(const Descriptor& params,
                               const input_t& input,
                               const result_t& result) const {
-        ONEDAL_ASSERT(result.get_labels().has_data());
-        ONEDAL_ASSERT(result.get_labels().get_row_count() == input.get_data().get_row_count());
-        ONEDAL_ASSERT(result.get_labels().get_column_count() == 1);
+        ONEDAL_ASSERT(result.get_responses().has_data());
+        ONEDAL_ASSERT(result.get_responses().get_row_count() == input.get_data().get_row_count());
+        ONEDAL_ASSERT(result.get_responses().get_column_count() == 1);
     }
 
     template <typename Context>
