@@ -76,12 +76,7 @@ public:
 
     descriptor_base();
 
-    /// The coefficient $k$ of the linear kernel.
-    /// @remark default = 1.0
     double get_scale() const;
-
-    /// The coefficient $b$ of the linear kernel.
-    /// @remark default = 0.0
     double get_shift() const;
 
 protected:
@@ -110,12 +105,12 @@ namespace v1 {
 ///                intermediate computations. Can be :expr:`float` or
 ///                :expr:`double`.
 /// @tparam Method Tag-type that specifies an implementation of algorithm. Can
-///                be :expr:`method::v1::dense`.
+///                be :expr:`method::dense`.
 /// @tparam Task   Tag-type that specifies the type of the problem to solve. Can
-///                be :expr:`task::v1::compute`.
-template <typename Float = detail::descriptor_base<>::float_t,
-          typename Method = detail::descriptor_base<>::method_t,
-          typename Task = detail::descriptor_base<>::task_t>
+///                be :expr:`task::compute`.
+template <typename Float = float,
+          typename Method = method::by_default,
+          typename Task = task::by_default>
 class descriptor : public detail::descriptor_base<Task> {
     static_assert(detail::is_valid_float_v<Float>);
     static_assert(detail::is_valid_method_v<Method>);
@@ -128,11 +123,26 @@ public:
     using method_t = Method;
     using task_t = Task;
 
+    /// Creates a new instance of the class with the default property values.
+    descriptor() = default;
+
+    /// The coefficient $k$ of the linear kernel.
+    /// @remark default = 1.0
+    double get_scale() const {
+        return base_t::get_scale();
+    }
+
     auto& set_scale(double value) {
         base_t::set_scale_impl(value);
         return *this;
     }
 
+    /// The coefficient $b$ of the linear kernel.
+    /// @remark default = 0.0
+    double get_shift() const {
+        return base_t::get_shift();
+    }
+
     auto& set_shift(double value) {
         base_t::set_shift_impl(value);
         return *this;
