@@ -107,8 +107,8 @@ public:
     using task_t = Task;
     using allocator_t = Allocator;
 
-    explicit descriptor(Allocator allocator) {
-        _alloc = allocator;
+    explicit descriptor(Allocator allocator = std::allocator<char>()) {
+        alloc_ = allocator;
     }
 
     kind get_kind() const {
@@ -130,11 +130,11 @@ public:
     }
 
     Allocator get_allocator() const {
-        return _alloc;
+        return alloc_;
     }
 
 private:
-    Allocator _alloc;
+    Allocator alloc_;
 };
 
 namespace detail {
