@@ -17,6 +17,8 @@
 #pragma once
 
 #include "oneapi/dal/detail/train_ops.hpp"
+#include "oneapi/dal/detail/spmd_policy.hpp"
+#include "oneapi/dal/spmd/communicator.hpp"
 
 namespace oneapi::dal {
 namespace v1 {
@@ -38,4 +40,25 @@ auto train(sycl::queue& queue, Args&&... args) {
 
 using v1::train;
 
+namespace preview {
+
+template <typename... Args>
+auto train(spmd::communicator<spmd::device_memory_access::none>& comm, Args&&... args) {
+    return dal::detail::train_dispatch(dal::detail::spmd_policy{ dal::detail::host_policy{}, comm },
+                                       std::forward<Args>(args)...);
+}
+
+#ifdef ONEDAL_DATA_PARALLEL
+template <typename... Args>
+auto train(spmd::communicator<spmd::device_memory_access::usm>& comm, Args&&... args) {
+    return dal::detail::train_dispatch(
+        dal::detail::spmd_policy<dal::detail::data_parallel_policy>{
+            dal::detail::data_parallel_policy{ comm.get_queue() },
+            comm },
+        std::forward<Args>(args)...);
+}
+#endif
+
+} // namespace preview
+
 } // namespace oneapi::dal
