@@ -33,7 +33,9 @@
 #include "services/internal/sycl/error_handling_sycl.h"
 #include "services/internal/sycl/level_zero_common.h"
 
-#if (defined(__SYCL_COMPILER_VERSION) && (__SYCL_COMPILER_VERSION >= 20200701))
+#if (defined(__SYCL_COMPILER_VERSION) && (__SYCL_COMPILER_VERSION >= 20211025))
+    #include <ext/oneapi/backend/level_zero.hpp>
+#elif (defined(__SYCL_COMPILER_VERSION) && (__SYCL_COMPILER_VERSION >= 20200701))
     #include <CL/sycl/backend/level_zero.hpp>
 #else
     #include <CL/sycl/backend/Intel_level0.hpp>
@@ -50,36 +52,98 @@ namespace sycl
 {
 namespace interface1
 {
+#define DAAL_LEVEL_ZERO_VERSION_SUFF          ".1"
+#define DAAL_LEVEL_ZERO_LIB_VERSIONED_NAME(n) #n DAAL_LEVEL_ZERO_VERSION_SUFF
+
 #ifdef __linux__
-static const char * zeLoaderName = "libze_loader.so";
+static const char * zeLoaderName = DAAL_LEVEL_ZERO_LIB_VERSIONED_NAME(libze_loader.so);
 static const int libLoadFlags    = RTLD_NOLOAD | RTLD_NOW | RTLD_LOCAL;
 #elif defined(_WIN64)
 static const char * zeLoaderName = "ze_loader.dll";
-static const int libLoadFlags    = 0;
+static const int libLoadFlags    = LOAD_LIBRARY_SEARCH_SYSTEM32;
 #else
     #error "Level Zero support is unavailable for this platform"
 #endif
 
 static const char * zeModuleCreateFuncName  = "zeModuleCreate";
 static const char * zeModuleDestroyFuncName = "zeModuleDestroy";
+static const char * zeKernelCreateFuncName  = "zeKernelCreate";
+static const char * zeKernelDestroyFuncName = "zeKernelDestroy";
+class ZeModule;
+
+class ZeKernel : public Base
+{
+    friend ZeModule;
+
+public:
+    ZeKernel(const ZeModule &) = delete;
+    ZeKernel & operator=(const ZeModule &) = delete;
+
+    ze_kernel_handle_t get() const { return _kernelLevelZero; }
+
+private:
+    explicit ZeKernel(ze_module_handle_t moduleLevelZero, const char * kernelName, Status & status)
+    {
+        static DynamicLibHelper zeLib(zeLoaderName, libLoadFlags, status);
+        DAAL_CHECK_STATUS_RETURN_VOID_IF_FAIL(status);
+
+        static zeKernelCreateFT stZeKernelCreateF = zeLib.getSymbol<zeKernelCreateFT>(zeKernelCreateFuncName, status);
+        DAAL_CHECK_STATUS_RETURN_VOID_IF_FAIL(status);
+
+        _zeKernelCreateF = stZeKernelCreateF;
+
+        ze_kernel_desc_t desc;
+        desc.stype       = ZE_STRUCTURE_TYPE_KERNEL_DESC;
+        desc.pNext       = nullptr;
+        desc.flags       = ze_kernel_flags_t(0);
+        desc.pKernelName = kernelName;
+
+        DAAL_CHECK_LEVEL_ZERO(_zeKernelCreateF(moduleLevelZero, &desc, &_kernelLevelZero), status);
+    }
+
+    zeKernelCreateFT _zeKernelCreateF;
+
+    ze_kernel_handle_t _kernelLevelZero;
+};
+
+typedef SharedPtr<ZeKernel> ZeKernelPtr;
 
 class ZeModule : public Base
 {
 public:
     static SharedPtr<ZeModule> create(cl::sycl::queue & deviceQueue, size_t binarySize, const uint8_t * pBinary, Status & status)
     {
-        const auto ptr = new ZeModule(deviceQueue, binarySize, pBinary, status);
-        if (!ptr) status |= ErrorMemoryAllocationFailed;
+        auto ptr = new ZeModule(deviceQueue, binarySize, pBinary, status);
+        if (!status)
+        {
+            if (ptr) delete ptr;
+            ptr = nullptr;
+        }
+        else if (!ptr)
+            status |= ErrorMemoryAllocationFailed;
         return SharedPtr<ZeModule>(ptr);
     }
 
     ZeModule(const ZeModule &) = delete;
     ZeModule & operator=(const ZeModule &) = delete;
 
-    cl::sycl::program getZeProgram() { return _program; }
+    ZeKernelPtr createKernel(const char * kernelName, Status & status)
+    {
+        auto ptr = new ZeKernel(_moduleLevelZero, kernelName, status);
+        if (!status)
+        {
+            if (ptr) delete ptr;
+            ptr = nullptr;
+        }
+        else if (!ptr)
+            status |= ErrorMemoryAllocationFailed;
+        return ZeKernelPtr(ptr);
+    }
+
+    ze_module_handle_t get() const { return _moduleLevelZero; }
 
 private:
-    ZeModule(cl::sycl::queue & deviceQueue, size_t binarySize, const uint8_t * pBinary, Status & status) : _program(deviceQueue.get_context())
+    explicit ZeModule(cl::sycl::queue & deviceQueue, size_t binarySize, const uint8_t * pBinary, Status & status)
     {
         static DynamicLibHelper zeLib(zeLoaderName, libLoadFlags, status);
         DAAL_CHECK_STATUS_RETURN_VOID_IF_FAIL(status);
@@ -96,19 +160,17 @@ private:
         desc.pInputModule = pBinary;
         desc.pBuildFlags  = "";
         desc.pConstants   = nullptr;
+        desc.pNext        = nullptr;
 
-        ze_module_handle_t _moduleLevelZero;
         DAAL_CHECK_LEVEL_ZERO(
             _zeModuleCreateF(deviceQueue.get_context().get_native<cl::sycl::backend::level_zero>(),
                              deviceQueue.get_device().get_native<cl::sycl::backend::level_zero>(), &desc, &_moduleLevelZero, nullptr),
             status);
-
-        status |= catchSyclExceptions(
-            [&]() mutable { _program = cl::sycl::level_zero::make<cl::sycl::program>(deviceQueue.get_context(), _moduleLevelZero); });
     }
 
-    cl::sycl::program _program;
     zeModuleCreateFT _zeModuleCreateF;
+
+    ze_module_handle_t _moduleLevelZero;
 };
 
 typedef SharedPtr<ZeModule> ZeModulePtr;
