@@ -55,6 +55,8 @@ cl::sycl::event sgemm_sycl(cl::sycl::queue *queue, MKL_LAYOUT layout, MKL_TRANSP
 
 cl::sycl::event dgemm_sycl(cl::sycl::queue *queue, MKL_LAYOUT layout, MKL_TRANSPOSE transa, MKL_TRANSPOSE transb, int64_t m, int64_t n, int64_t k, double alpha, cl::sycl::buffer<double,1> *a, int64_t lda, cl::sycl::buffer<double,1> *b, int64_t ldb, double beta, cl::sycl::buffer<double,1> *c, int64_t ldc, int64_t offset_a = 0, int64_t offset_b = 0, int64_t offset_c = 0);
 
+cl::sycl::event gemm_bf16bf16f32_sycl(cl::sycl::queue *queue, MKL_LAYOUT layout, MKL_TRANSPOSE transa, MKL_TRANSPOSE transb, int64_t m, int64_t n, int64_t k, float alpha, cl::sycl::buffer<bfloat16,1> *a, int64_t lda, cl::sycl::buffer<bfloat16,1> *b, int64_t ldb, float beta, cl::sycl::buffer<float,1>  *c,int64_t ldc, int64_t offset_a = 0, int64_t offset_b = 0, int64_t offset_c = 0);
+
 cl::sycl::event ssyrk_sycl(cl::sycl::queue *queue, MKL_LAYOUT layout, MKL_UPLO upper_lower, MKL_TRANSPOSE trans, int64_t n, int64_t k, float alpha, cl::sycl::buffer<float,1> *a, int64_t lda, float beta, cl::sycl::buffer<float,1> *c, int64_t ldc, int64_t offset_a = 0, int64_t offset_c = 0);
 
 cl::sycl::event dsyrk_sycl(cl::sycl::queue *queue, MKL_LAYOUT layout, MKL_UPLO upper_lower, MKL_TRANSPOSE trans, int64_t n, int64_t k, double alpha, cl::sycl::buffer<double,1> *a, int64_t lda, double beta, cl::sycl::buffer<double,1> *c, int64_t ldc, int64_t offset_a = 0, int64_t offset_c = 0);
@@ -74,6 +76,11 @@ static inline void dgemm_sycl(cl::sycl::queue *queue, MKL_TRANSPOSE transa, MKL_
     dgemm_sycl(queue, MKL_COL_MAJOR, transa, transb, m, n, k, alpha, a, lda, b, ldb, beta, c, ldc, offset_a, offset_b, offset_c);
 }
 
+static inline void gemm_bf16bf16f32_sycl(cl::sycl::queue *queue, MKL_TRANSPOSE transa, MKL_TRANSPOSE transb, int64_t m, int64_t n, int64_t k, float alpha, cl::sycl::buffer<bfloat16,1> *a, int64_t lda, cl::sycl::buffer<bfloat16,1> *b, int64_t ldb, float beta, cl::sycl::buffer<float,1> *c, int64_t ldc, int64_t offset_a = 0, int64_t offset_b = 0, int64_t offset_c = 0)
+{
+    gemm_bf16bf16f32_sycl(queue, MKL_COL_MAJOR, transa, transb, m, n, k, alpha, a, lda, b, ldb, beta, c, ldc, offset_a, offset_b, offset_c);
+}
+
 static inline void ssyrk_sycl(cl::sycl::queue *queue, MKL_UPLO upper_lower, MKL_TRANSPOSE trans, int64_t n, int64_t k, float alpha, cl::sycl::buffer<float,1> *a, int64_t lda, float beta, cl::sycl::buffer<float,1> *c, int64_t ldc, int64_t offset_a = 0, int64_t offset_c = 0)
 {
     ssyrk_sycl(queue, MKL_COL_MAJOR, upper_lower, trans, n, k, alpha, a, lda, beta, c, ldc, offset_a, offset_c);
