@@ -164,14 +164,14 @@ public:
 class batch_error : public oneapi::fpk::batch_error, public oneapi::fpk::lapack::exception
 {
 public:
-    batch_error(const std::string &function, const std::string &info, std::int64_t num_errors, cl::sycl::vector_class<std::int64_t> ids = {}, cl::sycl::vector_class<std::exception_ptr> exceptions = {})
+    batch_error(const std::string &function, const std::string &info, std::int64_t num_errors, std::vector<std::int64_t> ids = {}, std::vector<std::exception_ptr> exceptions = {})
             : oneapi::fpk::batch_error("LAPACK", function, info), oneapi::fpk::lapack::exception(this, num_errors), _ids(ids), _exceptions(exceptions) {}
     using oneapi::fpk::batch_error::what;
-    const cl::sycl::vector_class<std::int64_t>& ids() const { return _ids; }
-    const cl::sycl::vector_class<std::exception_ptr>& exceptions() const { return _exceptions; }
+    const std::vector<std::int64_t>& ids() const { return _ids; }
+    const std::vector<std::exception_ptr>& exceptions() const { return _exceptions; }
 private:
-    cl::sycl::vector_class<std::int64_t> _ids;
-    cl::sycl::vector_class<std::exception_ptr> _exceptions;
+    std::vector<std::int64_t> _ids;
+    std::vector<std::exception_ptr> _exceptions;
 };
 
 class invalid_argument : public oneapi::fpk::invalid_argument, public oneapi::fpk::lapack::exception
@@ -192,15 +192,15 @@ public:
 
 void potrf(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, cl::sycl::buffer<float>  &a, std::int64_t lda, cl::sycl::buffer<float>  &scratchpad, std::int64_t scratchpad_size);
 void potrf(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, cl::sycl::buffer<double> &a, std::int64_t lda, cl::sycl::buffer<double> &scratchpad, std::int64_t scratchpad_size);
-cl::sycl::event potrf(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, float  *a, std::int64_t lda, float  *scratchpad, std::int64_t scratchpad_size, const cl::sycl::vector_class<cl::sycl::event> &events = {});
-cl::sycl::event potrf(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, double *a, std::int64_t lda, double *scratchpad, std::int64_t scratchpad_size, const cl::sycl::vector_class<cl::sycl::event> &events = {});
+cl::sycl::event potrf(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, float  *a, std::int64_t lda, float  *scratchpad, std::int64_t scratchpad_size, const std::vector<cl::sycl::event> &events = {});
+cl::sycl::event potrf(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, double *a, std::int64_t lda, double *scratchpad, std::int64_t scratchpad_size, const std::vector<cl::sycl::event> &events = {});
 template <typename data_t, void* = nullptr>
 std::int64_t potrf_scratchpad_size(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, std::int64_t lda);
 
 void potrs(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, std::int64_t nrhs, cl::sycl::buffer<float>  &a, std::int64_t lda, cl::sycl::buffer<float>  &b, std::int64_t ldb, cl::sycl::buffer<float>  &scratchpad, std::int64_t scratchpad_size);
 void potrs(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, std::int64_t nrhs, cl::sycl::buffer<double> &a, std::int64_t lda, cl::sycl::buffer<double> &b, std::int64_t ldb, cl::sycl::buffer<double> &scratchpad, std::int64_t scratchpad_size);
-cl::sycl::event potrs(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, std::int64_t nrhs, float  *a, std::int64_t lda, float  *b, std::int64_t ldb, float  *scratchpad, std::int64_t scratchpad_size, const cl::sycl::vector_class<cl::sycl::event> &events = {});
-cl::sycl::event potrs(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, std::int64_t nrhs, double *a, std::int64_t lda, double *b, std::int64_t ldb, double *scratchpad, std::int64_t scratchpad_size, const cl::sycl::vector_class<cl::sycl::event> &events = {});
+cl::sycl::event potrs(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, std::int64_t nrhs, float  *a, std::int64_t lda, float  *b, std::int64_t ldb, float  *scratchpad, std::int64_t scratchpad_size, const std::vector<cl::sycl::event> &events = {});
+cl::sycl::event potrs(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, std::int64_t nrhs, double *a, std::int64_t lda, double *b, std::int64_t ldb, double *scratchpad, std::int64_t scratchpad_size, const std::vector<cl::sycl::event> &events = {});
 template <typename data_t, void* = nullptr>
 std::int64_t potrs_scratchpad_size(cl::sycl::queue &queue, oneapi::fpk::uplo uplo, std::int64_t n, std::int64_t nrhs, std::int64_t lda, std::int64_t ldb);
 
@@ -216,22 +216,21 @@ inline namespace column_major {
 
 DLL_EXPORT cl::sycl::event axpy(cl::sycl::queue &queue, std::int64_t n,
     float alpha, const float *x, std::int64_t incx, float *y, std::int64_t incy,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event axpy(cl::sycl::queue &queue, std::int64_t n,
     double alpha, const double *x, std::int64_t incx, double *y,
-    std::int64_t incy,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    std::int64_t incy, const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event axpy(cl::sycl::queue &queue, std::int64_t n,
     std::complex<float> alpha, const std::complex<float> *x, std::int64_t incx,
     std::complex<float> *y, std::int64_t incy,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event axpy(cl::sycl::queue &queue, std::int64_t n,
     std::complex<double> alpha, const std::complex<double> *x, std::int64_t incx,
     std::complex<double> *y, std::int64_t incy,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 
 DLL_EXPORT void axpy(cl::sycl::queue &queue, std::int64_t n, float alpha,
@@ -258,45 +257,45 @@ DLL_EXPORT cl::sycl::event gemm(cl::sycl::queue &queue, transpose transa,
     transpose transb, std::int64_t m, std::int64_t n, std::int64_t k,
     float alpha, const float *a, std::int64_t lda, const float *b,
     std::int64_t ldb, float beta, float *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event gemm(cl::sycl::queue &queue, transpose transa,
     transpose transb, std::int64_t m, std::int64_t n, std::int64_t k,
     double alpha, const double *a, std::int64_t lda, const double *b,
     std::int64_t ldb, double beta, double *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event gemm(cl::sycl::queue &queue, transpose transa,
     transpose transb, std::int64_t m, std::int64_t n, std::int64_t k,
     std::complex<float> alpha, const std::complex<float> *a, std::int64_t lda,
     const std::complex<float> *b, std::int64_t ldb, std::complex<float> beta,
     std::complex<float> *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event gemm(cl::sycl::queue &queue, transpose transa,
     transpose transb, std::int64_t m, std::int64_t n, std::int64_t k,
     std::complex<double> alpha, const std::complex<double> *a, std::int64_t lda,
     const std::complex<double> *b, std::int64_t ldb, std::complex<double> beta,
     std::complex<double> *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
-
-DLL_EXPORT cl::sycl::event gemm(cl::sycl::queue &queue, transpose transa,
-    transpose transb, std::int64_t m, std::int64_t n, std::int64_t k, half alpha,
-    const half *a, std::int64_t lda, const half *b, std::int64_t ldb, half beta,
-    half *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event gemm(cl::sycl::queue &queue, transpose transa,
     transpose transb, std::int64_t m, std::int64_t n, std::int64_t k,
-    float alpha, const half *a, std::int64_t lda, const half *b,
+    sycl::half alpha, const sycl::half *a, std::int64_t lda, const sycl::half *b,
+    std::int64_t ldb, sycl::half beta, sycl::half *c, std::int64_t ldc,
+    const std::vector<cl::sycl::event> &dependencies = {});
+
+DLL_EXPORT cl::sycl::event gemm(cl::sycl::queue &queue, transpose transa,
+    transpose transb, std::int64_t m, std::int64_t n, std::int64_t k,
+    float alpha, const sycl::half *a, std::int64_t lda, const sycl::half *b,
     std::int64_t ldb, float beta, float *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event gemm(cl::sycl::queue &queue, transpose transa,
     transpose transb, std::int64_t m, std::int64_t n, std::int64_t k,
     float alpha, const bfloat16 *a, std::int64_t lda, const bfloat16 *b,
     std::int64_t ldb, float beta, float *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 
 DLL_EXPORT void gemm(cl::sycl::queue &queue, transpose transa, transpose transb,
@@ -326,15 +325,16 @@ DLL_EXPORT void gemm(cl::sycl::queue &queue, transpose transa, transpose transb,
     std::int64_t ldc);
 
 DLL_EXPORT void gemm(cl::sycl::queue &queue, transpose transa, transpose transb,
-    std::int64_t m, std::int64_t n, std::int64_t k, half alpha,
-    cl::sycl::buffer<half, 1> &a, std::int64_t lda, cl::sycl::buffer<half, 1> &b,
-    std::int64_t ldb, half beta, cl::sycl::buffer<half, 1> &c, std::int64_t ldc);
+    std::int64_t m, std::int64_t n, std::int64_t k, sycl::half alpha,
+    cl::sycl::buffer<sycl::half, 1> &a, std::int64_t lda,
+    cl::sycl::buffer<sycl::half, 1> &b, std::int64_t ldb, sycl::half beta,
+    cl::sycl::buffer<sycl::half, 1> &c, std::int64_t ldc);
 
 DLL_EXPORT void gemm(cl::sycl::queue &queue, transpose transa, transpose transb,
     std::int64_t m, std::int64_t n, std::int64_t k, float alpha,
-    cl::sycl::buffer<half, 1> &a, std::int64_t lda, cl::sycl::buffer<half, 1> &b,
-    std::int64_t ldb, float beta, cl::sycl::buffer<float, 1> &c,
-    std::int64_t ldc);
+    cl::sycl::buffer<sycl::half, 1> &a, std::int64_t lda,
+    cl::sycl::buffer<sycl::half, 1> &b, std::int64_t ldb, float beta,
+    cl::sycl::buffer<float, 1> &c, std::int64_t ldc);
 
 DLL_EXPORT void gemm(cl::sycl::queue &queue, transpose transa, transpose transb,
     std::int64_t m, std::int64_t n, std::int64_t k, float alpha,
@@ -347,28 +347,25 @@ DLL_EXPORT void gemm(cl::sycl::queue &queue, transpose transa, transpose transb,
 DLL_EXPORT cl::sycl::event gemv(cl::sycl::queue &queue, transpose trans,
     std::int64_t m, std::int64_t n, float alpha, const float *a,
     std::int64_t lda, const float *x, std::int64_t incx, float beta, float *y,
-    std::int64_t incy,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    std::int64_t incy, const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event gemv(cl::sycl::queue &queue, transpose trans,
     std::int64_t m, std::int64_t n, double alpha, const double *a,
     std::int64_t lda, const double *x, std::int64_t incx, double beta, double *y,
-    std::int64_t incy,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    std::int64_t incy, const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event gemv(cl::sycl::queue &queue, transpose trans,
     std::int64_t m, std::int64_t n, std::complex<float> alpha,
     const std::complex<float> *a, std::int64_t lda, const std::complex<float> *x,
     std::int64_t incx, std::complex<float> beta, std::complex<float> *y,
-    std::int64_t incy,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    std::int64_t incy, const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event gemv(cl::sycl::queue &queue, transpose trans,
     std::int64_t m, std::int64_t n, std::complex<double> alpha,
     const std::complex<double> *a, std::int64_t lda,
     const std::complex<double> *x, std::int64_t incx, std::complex<double> beta,
     std::complex<double> *y, std::int64_t incy,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 
 DLL_EXPORT void gemv(cl::sycl::queue &queue, transpose trans, std::int64_t m,
@@ -400,24 +397,24 @@ DLL_EXPORT void gemv(cl::sycl::queue &queue, transpose trans, std::int64_t m,
 DLL_EXPORT cl::sycl::event syrk(cl::sycl::queue &queue, uplo upper_lower,
     transpose trans, std::int64_t n, std::int64_t k, float alpha, const float *a,
     std::int64_t lda, float beta, float *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event syrk(cl::sycl::queue &queue, uplo upper_lower,
     transpose trans, std::int64_t n, std::int64_t k, double alpha,
     const double *a, std::int64_t lda, double beta, double *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event syrk(cl::sycl::queue &queue, uplo upper_lower,
     transpose trans, std::int64_t n, std::int64_t k, std::complex<float> alpha,
     const std::complex<float> *a, std::int64_t lda, std::complex<float> beta,
     std::complex<float> *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 DLL_EXPORT cl::sycl::event syrk(cl::sycl::queue &queue, uplo upper_lower,
     transpose trans, std::int64_t n, std::int64_t k, std::complex<double> alpha,
     const std::complex<double> *a, std::int64_t lda, std::complex<double> beta,
     std::complex<double> *c, std::int64_t ldc,
-    const cl::sycl::vector_class<cl::sycl::event> &dependencies = {});
+    const std::vector<cl::sycl::event> &dependencies = {});
 
 
 DLL_EXPORT void syrk(cl::sycl::queue &queue, uplo upper_lower, transpose trans,
